@@ -8,6 +8,7 @@ from __future__ import (division, print_function, absolute_import,
                         unicode_literals)
 import numpy as np
 import scipy.optimize as so
+from scipy.integrate import simps, trapz
 from p_winds import tools
 
 
@@ -15,6 +16,69 @@ __all__ = ["sound_speed", "radius_sonic_point", "density_sonic_point",
            "structure"]
 
 
+# Average mean-molecular weight following the formulation of Lampón et al. 2020
+def average_molecular_weight(ion_fraction_profile, r_profile, v_profile,
+                             planet_mass, temperature, he_h_fraction=0.1 / 0.9):
+    """
+    Calculates the "average" mean molecular weight of the upper atmosphere
+    following Eq. A.3 in Lampón et al. 2020, in unit of proton mass.
+
+    Parameters
+    ----------
+    ion_fraction_profile (``numpy.ndarray``):
+        Hydrogen ion fraction in function of radial distance.
+
+    r_profile (``numpy.ndarray``):
+        Radial distance profile in unit of Jupiter radii. This is the
+        independent variable over which the profiles are described.
+
+    v_profile (``numpy.ndarray``):
+        Velocity profile in units of km / s in function of radial distance.
+
+    planet_mass (``float``):
+        Planetary mass in unit of Jupiter mass.
+
+    temperature (``float``):
+        Isothermal temperature of the outflow in unit of K.
+
+    he_h_fraction (``float``, optional):
+        Number fraction of He particles in relation to H particles. Default is
+        0.1 / 0.9.
+
+    Returns
+    -------
+    mu_bar (``float``):
+        "Average" mean molecular weight as defined by Eq. A.3 of Lampón et al.
+        2020, in unit of proton mass.
+    """
+    # Converting units
+    m_planet = planet_mass * 1.8981246e+27  # Planet mass in kg
+    r = r_profile * 71492000.0  # Radius profile in m
+    v_r = v_profile * 1000  # Velocity profile in unit of m / s
+
+    # Physical constants
+    k_b = 1.380649e-23  # Boltzmann's constant in J / K
+    grav = 6.6743e-11  # Gravitational constant in m ** 3 / kg / s ** 2
+
+    # Mean molecular weight in function of radial distance r
+    mu_r = (1 + 4 * he_h_fraction) / \
+        (1 + he_h_fraction + ion_fraction_profile)
+
+    # Eq. A.3 of Lampón et al. 2020 is a combination of several integrals, which
+    # we calculate here
+    int_1 = simps(mu_r / r ** 2, r)
+    int_2 = simps(mu_r * v_r, v_r)
+    int_3 = trapz(mu_r, 1 / mu_r)
+    int_4 = simps(1 / r ** 2, r)
+    int_5 = simps(v_r, v_r)
+    int_6 = 1 / mu_r[-1] - 1 / mu_r[0]
+    term_1 = grav * m_planet * int_1 + int_2 + k_b * temperature * int_3
+    term_2 = grav * m_planet * int_4 + int_5 + k_b * temperature * int_6
+    mu_bar = term_1 / term_2
+
+    return mu_bar
+
+
 # Speed of sound
 def sound_speed(temperature, h_fraction, ion_fraction=0.0):
     """
